| ## Zhou Yu 俞舟 Zhou (pronunced similar to Jo) Associate Professor Computer Science Department Columbia University Address: Schapiro CEPSR 723 530 West 120th Street, New York, NY 10027 Email: zy2461@columbia.edu CV [pdf]

### Welcome

I am an Associate Professor at the Computer Science Department, Columbia University. I am also a co-founder of Arklex.ai that centers its efforts on harnessing the power of AI Agents to empower and shape the future landscape of the workspace. Before that I was an Assistant Professor at UC Davis. I received my PhD at Language Technology Institute under School of Computer Science, Carnegie Mellon University 2017, working with Prof. Alan W Black and Prof. Alexander I. Rudnicky. 2015 summer and 2016 summer, I interned with Prof. David Suendermann-Oeft at ETS San Francisco Office on cloud based multimodal dialog systems. 2014 Fall, I interned with Dan Bohus and Eric Horvitz at Microsoft Research on situated multimodal dialogue systems. I was featured on Forbes 30 under 30 in Science in 2018. My team also won the 2018 Amazon Alexa Socialbot Competition. Our work on Persuasive Dialog Systems also won ACL 2019 best paper nomination.

Prior to CMU, I received a B.S. in Computer Science and a B.A. in Linguistics under English Language Major from Zhejiang University in 2011. I worked with Prof. Xiaofei He and Prof. Deng Cai on Machine Learning and Computer Vision. I also worked with Prof. Yunhua Qu on Machine Translation.

### Research Interests

I design algorithms for real-time intelligent interactive systems that coordinate with user actions that are beyond spoken languages, including non-verbal behaviors to achieve effective and natural communications. In particular, I optimize human-machine communication via studies of multimodal sensing and analysis, speech and natural language processing, machine learning and human-computer interaction. The central focus of my dissertation research is to bring together all the areas above to design, implement and deploy end-to-end real-time interactive intelligent systems that are able to plan globally considering interaction history and current user actions to achieve better user experience and task performance. Meanwhile, I enjoy collaborating with researchers with different backgrounds on interdisciplinary research in all area of science, such as health care, education and robotics.

### Talks

This is the teaching material of my COM 4705 Introduction to Natural Language Processing 2024 Fall Webpage

I generally recruite PhDs and interns every year, so don't send me generic email to ask about it. If you don't have much experience, please follow this LinkedIn post to get in contact.

We just released our Open-Source AI Agent framework with features such as mixed-control, task composition, human-intervention and continual learning, want to know more, please check here

Our recent work, ExACT on AI Agent planning is the top entry on various AI Agent Benchmark. Check it our, open source code coming soon

Slides from my rescent talk: AI Agents beyond ChatGPT slides

Our lab received one outstanding paper in ACL 2024 and another in NAACL 2024

Thanks Columbia University for the Provost's Junior Faculty Award 2023

Thanks Sony for the 2023 Faculty Award

Thanks Walmart AI lab for the 2023 Research Award

Thanks Cisco for the 2022 Faculty Award

Thanks IBM for the 2021 IBM Faculty Award

Thanks Adobe for the 2021 Adobe Faculty Award

Thanks Tencent for the 2021 Tencent Faculty Award

Please try our dialog data collection and evaluation tool kit LEGOEval code paper demo

I created the first Conversational AI course at Columbia 2021, Here is all the reading materials and corresponding slides.link

Recent talk at USC ISI, Teaching machines with natural language. video

New WeCNLP invited talk video on Builidng Dialog Systems with Less Supervsion video

Recent talk: Building Dialog Systems with Less Supervision slides

Recent talk: Gunrock, 2018 Amazon Alexa Socialbot Winner slides

Recent talk: Grounding Reinforcement Learning with Real-World Dialog Applications slides

Here is a Chinese verison of Multimodal Dialog Systems talk that targets to general public. video

### News

I designed a Conversational AI course in Columbia, here are the reading materials and slides[link]

Our paper Persuasion For Good was nominated for ACL 2019 best paper.

We won Amazon Alexa Prize with $500,000 webpage Please refer to our system report [pdf]

I was featured on Forbes 30 under 30 in Science webpage If you want to try our chatbot, just say "Alexa Let's chat!" to any Alexa device or download the App Amazon Alexa on your phone.

If you want to do a PhD with me, please read Mor's advice Applying PhD.

### PhD Students

Mingyang Zhou, graduated 2022, Now Researcher at Capital One

Dian Yu, graduated 2022, Now Researcher at Google Deepmind

Weiyan Shi, graduated 2023, Now Faculty at Northeastern

Sam Davidson, graduated 2024, Now Applied Scientist at Amazon AWS

Qingyang Wu, graduated 2024, Now Researcher at Together.ai

Kun Qian , graduated 2024, Now Scientist at Apple

Yanda Chen, graduated 2024, Now Researcher at Anthropic

Yu Li joined 2020

Max Chen, joined 2021, Graduate Fellowship for STEM Diversity

Sky Wang, joined 2021, NSF Graduate Fellowship

Matthew Toles, joined 2022, NSF Graduate Fellowship

Zachary Horvitz, joined 2023, Amazon Fellowship

Siyan(Sylvia) Li, joined 2023

Xuanming Zhang, joined 2023

Xiao Yu, joined 2023

Yunan(Lucy) Lu, joined 2024

### Selected Publications

ExACT: Teaching AI Agents to Explore with Reflective-MCTS and Exploratory Learning, Xiao Yu, Baolin Peng, Vineeth Vajipey, Hao Cheng, Michel Galley, Jianfeng Gao, Zhou Yu, arxiv 2024 website

Xiao Yu, Jinzhong Zhang, Zhou Yu ConFit: Improving Resume-Job Matching using Data Augmentation and Contrastive Learning, RecSys 2024

Xiao Yu, Qingyang Wu, Yu Li, Zhou Yu, LIONs: An Empirically Optimized Approach to Align Language Models, EMNLP 2024

Xuanming Zhang, Anthony Diaz, Zixun Chen, Qingyang Wu, Kun Qian, Erik Voss, Zhou Yu, DECOR: Improving Coherence in L2 English Writing with a Novel Benchmark for Incoherence Detection, Reasoning, and Rewriting, EMNLP 2024

Ryan Shea, Aymen Kallala, Xin Lucy Liu, Michael W. Morris, Zhou Yu, ACE: A LLM-based Negotiation Coaching System, EMNLP 2024

Ryan Shea, Zhou Yu, A Fairness-Driven Method for Learning Human-Compatible Negotiation Strategies, EMNLP 2024

Zachary Horvitz, Ajay Patel, Kanishk Singh, Chris Callison-Burch, Kathleen McKeown, Zhou Yu, TinyStyler: Efficient Few-Shot Text Style Transfer with Authorship Embeddings, EMNLP 2024 Findings

Kun Qian, Shunji Wan, Claudia Tang, Youzhi Wang, Xuanming Zhang, Maximillian Chen, Zhou Yu, VarBench: Robust Language Model Benchmarking Through Dynamic Variable Perturbation, EMNLP 2024 Findings

Siyan Li, Teresa Shao, Zhou Yu, Julia Hirschberg, EDEN: Empathetic Dialogues for English Learning, EMNLP 2024 Findings

Yu Li, Shang Qu, Jili Shen, Shangchao Min, Zhou Yu, Curriculum-Driven Edubot: A Framework for Developing Language Learning Chatbots Through Synthesizing Conversational Data SIGDIAL 2024

Yu-Wen Chen, Zhou Yu, Julia Hirschberg, MultiPA: A Multi-task Speech Pronunciation Assessment Model for Open Response Scenarios, INTERSPEECH 2024

Yanda Chen, Ruiqi Zhong, Narutatsu Ri, Chen Zhao, He He, Jacob Steinhardt, Zhou Yu, Kathleen McKeown, Do Models Explain Themselves? Counterfactual Simulatability of Natural Language Explanations, ICML 2024

Yanda Chen, Chen Zhao, Zhou Yu, Kathleen McKeown, He He, Parallel Structures in Pre-training Data Yield In-Context Learning, ACL 2024

Zachary Horvitz, Jingru Chen, Rahul Aditya, Harshvardhan Srivastava, Robert West, Zhou Yu, Kathleen McKeown, Getting Serious about Humor: Crafting Humor Datasets with Unfunny Large Language Models, ACL 2024, Outstanding paper

Xuanming Zhang, Zixun Chen, Zhou Yu, ProLex: A Benchmark for Language Proficiency-oriented Lexical Substitution, ACL 2024 Findings

Myeongseob Ko · Feiyang Kang · Weiyan Shi · Ming Jin · Zhou Yu · Ruoxi Jia, The Mirrored Influence Hypothesis: Efficient Data Influence Estimation by Harnessing Forward Passes, CVPR 2024

Xiao Yu, Baolin Peng, Michel Galley, Jianfeng Gao, Zhou Yu, Teaching Language Models to Self-Improve through Interactive Demonstrations, NAACL 2024, Outstanding paper

Zachary Horvitz, Ajay Patel, Chris Callison-Burch, Zhou Yu, Kathleen McKeown, ParaGuide: Guided Diffusion Paraphrasers for Plug-and-Play Textual Style Transfer, AAAI 2024

Jianguo Zhang, Kun Qian, Zhiwei Liu, Shelby Heinecke, Rui Meng, Ye Liu, Zhou Yu, Silvio Savarese, Caiming Xiong, DialogStudio: Towards Richest and Most Diverse Unified Dataset Collection for Conversational AI, arxiv 2023

Ryan Shea, Zhou Yu, Building Persona Consistent Dialogue Agents with Offline Reinforcement Learning EMNLP 2023

Xiao Yu, Qingyang Wu, Kun Qian, Zhou Yu, KRLS: Improving End-to-End Response Generation in Task Oriented Dialog with Reinforced Keywords Learning, EMNLP 2023

Libo Qin, Wenbo Pan, Qiguang Chen, Lizi Liao, Zhou Yu, Yue Zhang, Wanxiang Che, Min Li, End-to-end Task-oriented Dialogue: A Survey of Tasks, Methods, and Future Directions, EMNLP 2023

Xiao Yu, Maximillian Chen, Zhou YuPrompt-Based Monte-Carlo Tree Search for Goal-oriented Dialogue Policy Planning, EMNLP 2023

Sky CH-Wang, Arkadiy Saakyan, Oliver Li, Zhou Yu, Smaranda Muresan, Sociocultural Norm Similarities and Differences via Situational Alignment and Explainable Textual Entailment, EMNLP 2023

Rahul Goel, Waleed Ammar, Aditya Gupta, Siddharth Vashishtha, Motoki Sano, Faiz Surani, Max Chang, HyunJeong Choe, David Greene, Chuan He, Rattima Nitisaroj, Anna Trukhina, Shachi Paul, Pararth Shah, Rushin Shah, Zhou Yu, PRESTO: A Multilingual Dataset for Parsing Realistic Task-Oriented Dialogs, EMNLP 2023

Weiyan Shi, Emily Dinan, Adi Renduchintala, Daniel Fried, Athul Paul Jacob, Zhou Yu, Mike Lewis, AutoReply: Detecting Nonsense in Dialogue with Discriminative Replies EMNLP 2023 Findings

Yanda Chen, Chen Zhao, Zhou Yu, Kathleen McKeown, He He, On the Relation between Sensitivity and Accuracy in In-context Learning, EMNLP 2023 Findings

Yukun Huang, Yanda Chen, Zhou Yu, Kathleen McKeown, In-context Learning Distillation: Transferring Few-shot Learning Ability of Pre-trained Language Models AACL 2023

Yohei Hayamizu, Zhou Yu, and Shiqi Zhang, Learning Joint Policies for Human-Robot Dialog and Co-Navigation, IEEE/RSJ International Conference on Intelligent Robots (IROS), 2023

Qingyang Wu, Zhou Yu, Stateful Memory-Augmented Transformers for Efficient Dialogue Modeling, arxiv 2023, [pdf]

Derek Chen, Celine Lee, Yunan Lu, Domenic Rosati, Zhou Yu, Mixture of Soft Prompts for Controllable Data Generation, EMNLP 2023 Findings, [pdf]

Qingyang Wu, Deema Alnuhait, Derek Chen, Zhou Yu, Using Textual Interface to Align External Knowledge for End-to-End Task-Oriented Dialogue Systems,arxiv 2023, [pdf]

Maximillian Chen, Xiao Yu, Weiyan Shi, Urvi Awasthi, Zhou Yu Controllable Mixed-Initiative Dialogue Generation through Prompting ACL 2023, [pdf]

Yu Li, Baolin Peng, Pengcheng He, Michel Galley, Zhou Yu, Jianfeng Gao, DIONYSUS: A Pre-trained Model for Low-Resource Dialogue Summarization, ACL 2023, [pdf]

Kun Qian, Ryan Shea, Yu Li, Luke Kutszik Fryer, Zhou Yu, User Adaptive Language Learning Chatbots with a Curriculum, AIED 2023,[pdf]

Yanda Chen, Chen Zhao, Zhou Yu, Kathleen McKeown, He He, On the Relation between Sensitivity and Accuracy in In-context Learning, arxiv 2023 [pdf]

Max Chen, Zhou Yu, Pre-Finetuning for Few-Shot Emotional Speech Recognition, Interspeech 2023 [odf]

Yukun Huang, Yanda Chen, Zhou Yu, Kathleen McKeown, In-context Learning Distillation: Transferring Few-shot Learning Ability of Pre-trained Language Models arxiv 2023, [pdf]

Baolin Peng, Michel Galley, Pengcheng He, Hao Cheng, Yujia Xie, Yu Hu, Qiuyuan Huang, Lars Liden, Zhou Yu, Weizhu Chen, Jianfeng Gao, Check Your Facts and Try Again: Improving Large Language Models with External Knowledge and Automated Feedback, arXiv 2023 [pdf]

Rahul Goel, Waleed Ammar, Aditya Gupta, Siddharth Vashishtha, Motoki Sano, Faiz Surani, Max Chang, HyunJeong Choe, David Greene, Kyle He, Rattima Nitisaroj, Anna Trukhina, Shachi Paul, Pararth Shah, Rushin Shah, Zhou Yu, PRESTO: A Multilingual Dataset for Parsing Realistic Task-Oriented Dialogs, arxiv 2023 [pdf]

Maximillian Chen, Caitlyn K. Chen, Xiao Yu and Zhou Yu, FastKASSIM: A Fast Tree Kernel-Based Syntactic Similarity Metric, EACL 2023 [pdf]

Kushal Chawla, Weiyan Shi, Jingwen Zhang, Gale Lucas, Zhou Yu and Jonathan Gratch, Social Influence Dialogue Systems: A Survey of Datasets and Models For Social Influence Tasks, EACL 2023 [pdf]

Derek Chen, Kun Qian and Zhou Yu, Stabilized In-Context Learning with Pre-trained Language Models for Few Shot Dialogue State Tracking, EACL 2023 Findings [pdf]

Maximillian Chen, Alexandros Papangelis, Chenyang Tao, Seokhwan Kim, Andy Rosenbaum, Yang Liu, Zhou Yu and Dilek Hakkani-Tur, PLACES: Prompting Language Models for Social Conversation Synthesis EACL 2023 Findings [pdf]

Yingwen Fu, Wenjie Ou, Zhou Yu, and Yue Lin, MIGA: A Unified Multi-task Generation Framework for Conversational Text-to-SQL, AAAI 2023[pdf]

Weiyan Shi, Ryan Patrick Shea, Si Chen, Chiyuan Zhang, Ruoxi Jia and Zhou Yu, Just Fine-tune Twice: Selective Differential Privacy for Large Language Models, EMNLP 2022 [pdf]

David Gros, Yu Li and Zhou Yu, Robots-Dont-Cry v1: Understanding Falsely Anthropomorphic Utterances in Dialog Systems, EMNLP 2022[pdf]

Sky CH-Wang, Evan Li, Oliver Li, Smaranda Muresan and Zhou Yu, Affective Idiosyncratic Responses to Music, EMNLP 2022 [pdf]

Mingyang Zhou, Grace Luo, Anna Rohrbach and Zhou Yu, Focus! Relevant and Sufficient Context Selection for News Image Captioning, EMNLP 2022 Findings [pdf]

Maximillian Chen, Weiyan Shi, Feifan Yan, Ryan Hou, Jingwen Zhang, Saurav Sahay and Zhou Yu, Seamlessly Integrating Factual Information and Social Content with Persuasive Dialogue, AACL 2022 [pdf]

Qingyang Wu, Zhenzhong Lan, Kun Qian, Jing Gu, Alborz Geramifard, Zhou Yu, Memformer: A Memory-Augmented Transformer for Sequence Modeling, AACL Findings 2022 [pdf]

Libo Qin, Qiguang Chen, Tianbao Xie, Qian Liu, Shijue Huang, Wanxiang Che and Zhou Yu,CGIM: A Cycle Guided Interactive Learning Model for Consistency Identification in Task-oriented Dialogue, Coling 2022 [pdf]

Lu Sun, Yuhan Liu, Grace Joseph, Yu Zhou, Steven P. Dow and Haiyi Zhu, Comparing experts and crowds for AI data work: allocating human intelligence to design a conversational agent, HCOMP 2022 [pdf]

Liang Qiu, Yizhou Zhao, Yuan Liang, Pan Lu, Weiyan Shi, Zhou Yu and Song-Chun Zhu, Towards Socially Intelligent Agents with Mental State Transition and Human Value, SIGDIAL 2022 [pdf]

Qingyang Wu, Song Feng, Derek Chen, Sachindra Joshi, Luis Lastras and Zhou Yu, DG2: Data Augmentation Through Document Grounded Dialogue Generation, SIGDIAL 2022

Baolin Peng, Michel Galley, Pengcheng He, Chris Brockett, Lars Liden, Elnaz Nouri, Zhou Yu, Bill Dolan, Jianfeng Gao, GODEL: Large-Scale Pre-Training for Goal-Directed Dialog [pdf] [code] [blog]

Weiyan Shi, Aiqi Cui, Evan Li, Ruoxi Jia and Zhou Yu, Selective Differential Privacy for Language Models, NAACL 2022 [pdf][code]

Yu Li, Baolin Peng, Yelong Shen, Yi Mao, Lars Liden, Zhou Yu, Jianfeng Gao, Knowledge-Grounded Dialogue Generation with a Unified Knowledge Representation, NAACL 2022[pdf]

Kun Qian, Ahmad Beirami, Satwik Kottur, Shahin Shayandeh, Paul Crook, Alborz Geramifard, Zhou Yu, Chinnadhurai Sankar, Database Search Results Disambiguation for Task-Oriented Dialog Systems, NAACL 2022[pdf]

Xun Yuan, Sam Pham, Sam Davidson, Zhou Yu, ErAConD: Error Annotated Conversational Dialog Dataset for Grammatical Error Correction, NAACL 2022[pdf]

Mingyang Zhou, Licheng Yu, Amanpreet Singh, Mengjiao Wang, Zhou Yu, Ning Zhang, Unsupervised Vision-and-Language Pre-training via Retrieval-based Multi-Granular Alignment, CVPR 2022 [pdf]

Bowen Yang, Cong Han, Yu Li, Lei Zuo, Zhou Yu, Improving Conversational Recommendation Systems’ Quality with Context-Aware Item Meta-Information, NAACL 2022 Findings [pdf]

Yu Li, Chun-Yen Chen, Dian Yu, Sam Davidson, Ryan Hou, Xun Yuan, Yinghua Tan, Derek Pham, Zhou Yu, Using Chatbots to Teach Languages, Learning at Scale, 2022[pdf]

Ying Xu, Dakuo Wang, Mo Yu, Daniel Ritchie, Bingsheng Yao, Tongshuang Wu, Zheng Zhang, Toby Jia-Jun Li, Nora Bradford, Branda Sun, Tran Bao Hoang, Yisi Sang, Yufang Hou, Xiaojuan Ma, Diyi Yang, Nanyun Peng, Zhou Yu, Mark Warschauer, Fantastic Questions and Where to Find Them: FairytaleQA--An Authentic Dataset for Narrative Comprehension, ACL 2022 [pdf]

Yingwen_Fu, Wenjie Ou, Zhou Yu, Yue Lin, Effective Unsupervised Constrained Text Generation based on Perturbed Masking, ACL 2022 Findings [pdf]

Matthew Marge, Carol Espy-Wilson, Nigel G Ward, Abeer Alwan, Yoav Artzi, Mohit Bansal, Gil Blankenship, Joyce Chai, Hal Daumé III, Debadeepta Dey, Mary Harper, Thomas Howard, Casey Kennington, Ivana Kruijff-Korbayová, Dinesh Manocha, Cynthia Matuszek, Ross Mead, Raymond Mooney, Roger K Moore, Mari Ostendorf, Heather Pon-Barry, Alexander I Rudnicky, Matthias Scheutz, Robert St Amant, Tong Sun, Stefanie Tellex, David Traum and Zhou Yu, Spoken language interaction with robots: Recommendations for future research, Computer Speech and Language, 2022 [pdf]

Derek Chen and Zhou Yu, GOLD: Improving Out-of-Scope Detection in Dialogues using Data Augmentation, EMNLP 2021 [pdf][code]

Andrea Madotto, Zhaojiang Lin, Zhenpeng Zhou, Seungwhan Moon, Paul Crook, Bing Liu, Zhou Yu, Eunjoon Cho, Pascale Fung and Zhiguang Wang, Continual Learning in Task-Oriented Dialogue Systems, EMNLP 2021 [pdf]

Zhaojiang Lin, Bing Liu, Andrea Madotto, Seungwhan Moon, Zhenpeng Zhou, Paul Crook, Zhiguang Wang, Zhou Yu, Eunjoon Cho, Rajen Subba and Pascale Fung, Zero-Shot Dialogue State Tracking via Cross-Task Transfer, EMNLP 2021 [pdf]

Weiyan Shi, Yu Li, Saurav Sahay and Zhou Yu, Refine and Imitate: Reducing Repetition and Inconsistency in Persuasion Dialogues via Reinforcement Learning and Human Demonstration, EMNLP 2021 Findings [pdf]

Dian Yu, Zhou Yu and Kenji Sagae, Attribute Alignment: Controlling Text Generation from Pre-trained Language Models, EMNLP 2021 Findings [pdf]

Jun Zhang, Yan Yang, Chencai Chen, liang he and Zhou Yu, KERS: A Knowledge-Enhanced Framework for Recommendation Dialog Systems with Multiple Subgoals, EMNLP 2021 Findings [pdf]

Kai-Hui Liang, Weiyan Shi, Yoojung Oh, Jingwen Zhang, Zhou Yu, Discovering Chatbot's Self-Disclosure's Impact on User Trust, Affinity, and Recommendation Effectiveness, arXiv [pdf]

Kai-Hui Liang, Patrick Lange, Yoo Jung Oh, Jingwen Zhang, Yoshimi Fukuoka and Zhou Yu, Evaluation of In-Person Counseling Strategies To Develop Physical Activity Chatbot for Women, SIGDIAL 2021 [pdf]

Satwik Kottur, Chinnadhurai Sankar, Zhou Yu and Alborz Geramifard, DialogStitch: Synthetic Deeper and Multi-Context Task-Oriented Dialogs, SIGDIAL 2021 [pdf]

Minh Nguyen and Zhou Yu, Improving Named Entity Recognition in Spoken Dialog Systems by Context and Speech Pattern Modeling, SIGDIAL 2021 [pdf]

Lu Pan, Liang Qiu, Jiaqi Chen, Tony Xia, Yizhou Zhao, Wei Zhang, Zhou Yu, Xiaodan Liang, and Song-Chun Zhu, IconQA: A New Benchmark for Abstract Diagram Understanding and Visual Language Reasoning. NeurIPS 2021, Datasets and Benchmarks Track.[pdf]

Kun Qian, Ahmad Beirami, Zhouhan Lin, Ankita De, Alborz Geramifard, Zhou Yu and Chinnadhurai Sankar, Annotation Inconsistency and Entity Bias in MultiWOZ, SIGDIAL 2021 [pdf]

Jing Gu, Qingyang Wu, Chongruo Wu, Weiyan Shi and Zhou Yu, PRAL: A Tailored Pre-Training Model for Task-Oriented Dialog Generation, ACL 2021 [pdf][code]

Vojtěch Hudeček, Ondřej Dušek and Zhou Yu, Discovering Dialogue Slots with Weak Supervision, ACL 2021 [pdf]

Weixin Liang, Kai-Hui Liang and Zhou Yu, HERALD: An Annotation Efficient Method to Detect User Disengagement in Social Conversations, ACL 2021 [pdf][code and data][video]

David Gros, Yu Li and Zhou Yu, The R-U-A-Robot Dataset: Helping Avoid Chatbot Deception by Detecting User Questions About Human or Non-Human Identity, ACL 2021 [pdf][code and data]

Siyang Liu, Chujie Zheng, Orianna Demasi, Sahand Sabour, Yu Li, Zhou Yu, Yong Jiang and Minlie Huang, Towards Emotional Support Dialogue Systems, ACL 2021 [pdf]

Liang Qiu, Yuan Liang, Yizhou Zhao, Pan Lu, Baolin Peng, Zhou Yu, Ying Nian Wu and Song-Chun Zhu, SocAoG: Incremental Graph Parsing for Social Relation Inference in Dialogues, ACL 2021 [pdf] [code]

Meng Zhou, Zechen Li, Bowen Tan, Guangtao Zeng, Wenmian Yang, Xuehai He, Zeqian Ju, Subrato Chakravorty, Shu Chen, Xingyi Yang, Yichen Zhang, Qingyang Wu, Zhou Yu, Kun Xu, Eric Xing and Pengtao Xie, On the Generation of Medical Dialogs for COVID-19, ACL 2021 [pdf] [code and data]

Derek Chen, Howard Chen, Yi Yang, Alexander Lin and Zhou Yu, Action-Based Conversations Dataset:A Corpus for Building More In-Depth Task-Oriented Dialogue Systems, NAACL 2021 [pdf] [code and data]

Zhaojiang Lin, Bing Liu, Seungwhan Moon, Paul Crook, Zhenpeng Zhou, Zhiguang Wang, Zhou Yu, Andrea Madotto, Eunjoon Cho, Rajen Subba, Leveraging Slot Descriptions for Zero-Shot Cross-Domain Dialogue State Tracking, NAACL 2021 [pdf]

Mingyang Zhou, Luowei Zhou, Yu Cheng, Linjie Li, Zhou Yu, Jingjing Liu, UC2: Universal Cross-lingual Cross-modal Vision-and-Language Pretraining, CVPR 2021 [pdf] [video][code and data]

Qingyang Wu, Lei Li and Zhou Yu, TextGAIL: Generative Adversarial Imitation Learning for Text Generation, AAAI 2021 [pdf][code]

Jing Gu, Qingyang Wu and Zhou Yu, Perception Score: A Learned Metric for Open-ended Text Generation Evaluation, AAAI 2021[pdf]

Kun Qian, Wei Wei and Zhou Yu, A Student-Teacher Architecture for Dialog Domain Adaptation under the Meta-Learning Setting. AAAI 2021[pdf][code]

Jing Gu, Mostafa Mirshekari, Zhou Yu and Aaron Sisto, ChainCQG: Flow-Aware Conversational Question Generation, EACL 2021 [pdf][code]

Qingyang Wu, Yichi Zhang, Yu Li and Zhou Yu, Alternating Recurrent Dialog Model with Large-scale Pre-trained Language Models, EACL 2021 [pdf][code]

Dian Yu and Zhou Yu, MIDAS: A Dialog Act Annotation Scheme for Open Domain Human Machine Spoken Conversations, EACL 2021 [pdf][code]

David Gros, Hariharan Sezhiyan, Prem Devanbu, Zhou Yu, Code to Comment "Translation": Data, Metrics, Baselining & Evaluation, ASE 2020 [pdf]

Shirley Anugrah Hayati, Dongyeop Kang, Qingxiaoyang Zhu, Weiyan Shi and Zhou Yu, INSPIRED: Toward Sociable Recommendation Dialog Systems. EMNLP 2020 [pdf][code and data]

Liang Qiu, Yizhou Zhao, Weiyan Shi, Yuan Liang, Feng Shi, Tao Yuan, Zhou Yu, Song-Chun Zhu, Structured Attention for Unsupervised Dialogue Structure Induction, EMNLP 2020 [pdf]

Orianna Demasi, Yu Li, Zhou Yu, A Multi-Persona Chatbot for Hotline Counselor Training, Findings in EMNLP 2020, [pdf]

Weixin Liang, James Zou and Zhou Yu, ALICE: Active Learning with Contrastive Natural Language Explanations, EMNLP 2020 [pdf]

Weixin Liang, James Zou and Zhou Yu, Beyond User Self-Reported Likert Scale Ratings: A Comparison Model for Automatic Dialog Evaluation, ACL 2020 [pdf]

Silin Gao, Yichi Zhang, Zhijian Ou and Zhou Yu, Paraphrase Augmented Task-Oriented Dialog Generation, ACL 2020 [pdf]

Jiaying Hu, Yan Yang, Chencai Chen, Liang He and Zhou Yu, SAS: Dialogue State Tracking via Slot Attention and Slot Information Sharing, ACL 2020 [pdf]

Yiheng Zhou, Yulia Tsvetkov, Alan Black, and Zhou Yu, Augmenting Non-Collaborative Dialog Systems with Explicit Semantic and Strategic Dialog History, ICLR 2020, [pdf]

Weiyan Shi, Yoo Jung Oh, Xuewei Wang, Saurav Sahay, Jingwen Zhang, and Zhou Yu, Effects of Persuasive Dialogues: Testing Bot Identities and Inquiry Strategies, CHI 2020 [pdf]

Qingyang Wu, Lei Li, Hao Zhou, Ying Zeng and Zhou Yu, Importance-Aware Learning for Neural Headline Editing, AAAI 2020 [pdf]

Yu Li, Kun Qian, Weiyan Shi and Zhou Yu, End-to-End Trainable Non-Collaborative Dialog System, AAAI 2020 [pdf]

Xiyuan Zhang, Chenxi Li, Sam Davidson, Dian Yu and Zhou Yu, Filling Conversation Ellipsis for Better Social Dialog Understanding, AAAI 2020 [pdf]

Weixin Liang, Youzhi Tian, Chengcai Chen and Zhou Yu, MOSS: End-to-End Dialog System Framework with Modular Supervision, AAAI 2020 [pdf]

Yichi Zhang, Zhijian Ou and Zhou Yu, Task-Oriented Dialog Systems that Consider Multiple Appropriate Responses under the Same Context, AAAI 2020 [pdf] [code]

Dian Yu & Zhou Yu, MIDAS: A Dialog Act Annotation Scheme for Open Domain Human Machine Spoken Conversations, arXiv [pdf]

Mingyang Zhou, Joshua Arnold, Zhou Yu, Building Task-Oriented Visual Dialog Systems Through Alternative Optimization Between Dialog Policy and Language Generation, EMNLP 2019 [pdf]

Weiyan Shi, Kun Qian, Xuewei Wang, Zhou Yu, How to Build User Simulators to Train RL-based Dialog Systems, EMNLP 2019 [pdf]

Sam Davidson, Dian Yu, Zhou Yu, Dependency Parsing for Spoken Dialog Systems, EMNLP 2019 [pdf]

Dian Yu, et al., Gunrock: A Social Bot for Complex and Engaging Long Conversations, EMNLP 2019 demo [pdf]

Michelle Cohn, Chun-Yen Chen and Zhou Yu, A Large-Scale User Study of an Alexa Prize Chatbot: Effect of TTS Dynamism on Perceived Quality of Social Dialog, SIGDIAL 2019 [pdf]

Kun Qian & Zhou Yu, Domain Adaptive Dialog Generation via Meta Learning, ACL 2019 [pdf]

Xuewei Wang, Weiyan Shi, Richard Kim, Yoo Jung Oh, Sijia Yang, Jingwen Zhang, Zhou Yu, Persuasion for Good: Towards a Personalized Persuasive Dialogue System for Social Good, ACL 2019[pdf], [data and code] ** best paper nomination

Weiyan Shi, Tiancheng Zhao, Zhou Yu, Unsupervised Dialog Structure Learning, NAACL 2019 [pdf]

Chen et al., Gunrock: Building A Human-Like Social Bot By Leveraging Large Scale Real User Data [pdf]

Jiaao Chen, Jianshu Chen and Zhou Yu, Incorporating Structured Commonsense Knowledge in Story Completion, AAAI 2019 [pdf]

Youzhi Tian, Zhiting Hu and Zhou Yu, Structured Content Preservation for Unsupervised Text Style Transfer, arXiv 2018 [pdf]

Zijie Zhu, Xuewei Wang, Aakaash Kapoor, Tingrui Pan and Zhou Yu, EIS: A Wearable Device for Epidermal American Sign Language Recognition, IMWUT 2018 (Ubicomp 2019)[pdf]

Mingyang Zhou, Runxiang Cheng, Yong Jae Lee and Zhou Yu, A Visual Attention Grounding Neural Model for Multimodal Machine Translation, EMNLP 2018 [pdf][data]

Weiming Wen, Songwen Su and Zhou Yu, Cross-Lingual Cross-Platform Rumor Verification Pivoting on Multimedia Content, EMNLP 2018 [pdf] [code&data]

Jiaping Zhang, Tiancheng Zhao and Zhou Yu, Multimodal Hierarchical Reinforcement Learning Policy for Task-Oriented Visual Dialog, SIGDIAL 2018 [pdf]

Weiyan Shi and Zhou Yu, Sentiment Adaptive End-to-End Dialog Systems, ACL 2018 [pdf]

Ryant et al., Enhancement and Analysis of Conversational Speech: JSALT 2017, ICAASP 2018 [pdf]

Zhou Yu, Alan W Black and Alexander I. Rudnicky, Learning Conversational Systems that Interleave Task and Non-Task Content, IJCAI 2017 [pdf]

Zhou Yu, Vikram Ramanarayanan, Patrick Lange, and David Suendermann-Oeft. An open-source multimodal dialog system with real-time engagement tracking for job interview trainingapplications.In IWSDS, 2017 [pdf]

Zhou Yu, Ziyu Xu, Alan W Black and Alexander Rudnicky, Strategy and Policy Learning for Non-Task-Oriented Conversational Systems, SIGDIAL 2016. [pdf]

Zhou Yu, Leah Nicolich-Henkin, Alan W Black and Alexander Rudnicky, A Wizard-of-Oz Study on A Non-Task-Oriented Dialog Systems that Reacts to User Engagement, SIGDIAL 2016. [pdf]

Sean Andrist, Dan Bohus, Zhou Yu, Eric Horvitz, Are You Messing with Me?: Querying about the Sincerity of Interactions in the Open World. HRI 2016. [pdf]

Zhou Yu, Dan Bohus and Eric Horvitz, Incremental Coordination: Attention-Centric Speech Production in a Physically Situated Conversational Agent, SIGDIAL 2015. [pdf]

### Demo Videos

TickTock: a multimodal chatbot with user engagement coordination
- below is a demo of using automatically generated conversational strategy to improve user engagement.

Direction-giving Robot: a direction-giving humanoid robot with user attention coordination
- below is a demo and some real user cases of people interacting with the robot.

HALEF: a distributed web-based multimodal dialog system with user engagement coordination
- below is a demo of a Amazon Turker interacting with our job interview training application via a web browser. It live-streams videos from usrs' local webcam to the server.